@@ -1,3 +1,5 @@
+from time import sleep
+
 from django.conf import settings
 from django.core.management.base import BaseCommand
 from django_sqs_extended_client.aws.sns_client_extended import SNSClientExtended
@@ -15,8 +17,25 @@ class Command(BaseCommand):
             type=str,
         )
 
+        parser.add_argument(
+            '-s',
+            '--sleep_poll_seconds',
+            type=float,
+            default=0.2
+        )
+
+        parser.add_argument(
+            '-e',
+            '--exit_after_max_iterations_count',
+            type=int,
+            default=200
+        )
+
     def handle(self, *args, **options):
         queue_code = options['queue_code']
+        sleep_poll_seconds = options['sleep_poll_seconds']
+        exit_after_max_iterations_count = options['exit_after_max_iterations_count']
+        iterations = 0
 
         try:
             sqs_event = settings.SQS_EVENTS[queue_code]
@@ -31,6 +50,11 @@ class Command(BaseCommand):
         signal_handler = SignalHandler()
 
         while not self.get_received_signal(signal_handler=signal_handler):
+            iterations = iterations + 1
+            if iterations > exit_after_max_iterations_count:
+                print(f'Exiting after {exit_after_max_iterations_count} iterations.')
+                return
+
             sns = SNSClientExtended(settings.AWS_ACCESS_KEY_ID, settings.AWS_SECRET_ACCESS_KEY,
                                     settings.AWS_DEFAULT_REGION,
                                     settings.AWS_S3_QUEUE_STORAGE_NAME)
@@ -42,6 +66,7 @@ class Command(BaseCommand):
                     attributes = body.get('MessageAttributes')
                     self.process_event(queue_code=queue_code, content_data=content, attributes=attributes)
                     sns.delete_message(queue_url, message.get('ReceiptHandle'))
+            sleep(sleep_poll_seconds)
 
     @staticmethod
     def get_received_signal(signal_handler: SignalHandler):
